BFD
URLs Summary
URL | GET | POST | PATCH | PUT | DELETE |
|---|---|---|---|---|---|
/rest/v1/running/bfd | Y | N | Y | N | Y |
/rest/v1/running/bfd/accelerate-profile/{name} | Y | Y | Y | N | Y |
/rest/v1/running/bfd/multi-hop-session/{dest-addr}/{source-addr}/{vrf} | Y | Y | Y | N | Y |
/rest/v1/running/bfd/profile/{profile-name} | Y | Y | Y | N | Y |
/rest/v1/running/bfd/single-hop-session/{dest-addr}/{vrf}/{interface} | Y | Y | Y | N | Y |
/rest/v1/rpc/clear-bfd-counters | N | Y | N | N | N |
/rest/v1/rpc/show-bfd-brief | N | Y | N | N | N |
/rest/v1/rpc/show-bfd-counters | N | Y | N | N | N |
/rest/v1/rpc/show-bfd-peer | N | Y | N | N | N |
Examples
Clear BFD session counters.
POST HTTPS://{switch IP}/rest/v1/rpc/clear-bfd-countersShow BFD session brief information.
POST HTTPS://{switch IP}/rest/v1/rpc/show-bfd-brief
{"vrf": "default"}Show BFD session counters.
POST HTTPS://{switch IP}/rest/v1/rpc/show-bfd-countersShow BFD peer
POST HTTPS://{switch IP}/rest/v1/rpc/show-bfd-peer
{"dest-addr": "10.169.1.1"}Get all BFD information.
GET HTTPS://{switch IP}/rest/v1/running/bfdCreate a BFD accelerate profile.
POST HTTPS://{switch IP}/rest/v1/running/bfd/accelerate-profile
{
"name": "test",
"detect-multiplier": "15",
"required-receive-interval": "1000",
"desired-transmit-interval": "1000",
"shutdown": "false"
}Create a BFD normal profile.
POST HTTPS://{switch IP}/rest/v1/running/bfd/profile
{
"profile-name": "test333",
"detect-multiplier": 100,
"required-receive-interval": 200,
"desired-transmit-interval": 300,
"shutdown": "true",
"passive-mode": "true",
"required-echo-receive-interval": 400,
"desired-echo-transmit-interval": 500,
"minimum-ttl": 123,
"echo-mode": "false"
}Create a BFD multi-hop session.
POST HTTPS://{switch IP}/rest/v1/running/bfd/multi-hop-session
{
"dest-addr": "2.2.2.2",
"source-addr": "1.2.3.4",
"vrf": "Vrftest",
"profile-name": "test111",
"detect-multiplier": 3,
"required-receive-interval": 300,
"desired-transmit-interval": 300,
"shutdown": "false",
"minimum-ttl": 254,
"passive-mode": "false"
}Create a BFD single-hop session.
POST HTTPS://{switch IP}/rest/v1/running/bfd/single-hop-session
{
"dest-addr": "3.3.3.3",
"vrf": "Vrftest",
"interface": "Ethernet15",
"profile-name": "testcreate",
"detect-multiplier": 253,
"required-receive-interval": 400,
"desired-transmit-interval": 500,
"shutdown": "true",
"passive-mode": "true",
"required-echo-receive-interval": 600,
"desired-echo-transmit-interval": 700,
"echo-mode": "false"
}Properties Descriptions
BFD single hop sessions
Tree Diagrams
+--rw bfd
+--rw single-hop-session* [dest-addr vrf interface]
| +--rw dest-addr
| +--rw vrf
| +--rw interface
| +--rw source-addr?
| +--rw profile-name?
| +--rw detect-multiplier?
| +--rw required-receive-interval?
| +--rw desired-transmit-interval?
| +--rw shutdown?
| +--rw passive-mode?
| +--rw required-echo-receive-interval?
| +--rw desired-echo-transmit-interval?
| +--rw echo-mode?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
bfd | M | | Path-only node, has no configurable value. |
single-hop-session | M | | (sub-property of bfd) Path-only node, has no configurable value. |
dest-addr | M | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of single-hop-session) BFD remote IP address. |
vrf | M | "default" vrf name | (sub-property of single-hop-session) Name of VRF instance. The default VRF is "default" |
interface | M | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of single-hop-session) Name of interface. |
source-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of single-hop-session) BFD local IP address. |
profile-name | O | string | (sub-property of single-hop-session) BFD profile name |
detect-multiplier | O | 2..255 | (sub-property of single-hop-session) peer detection multiplier Default value: 3 |
required-receive-interval | O | 10..60000 | (sub-property of single-hop-session) Minimum desired control packet receive interval Default value: 300 |
desired-transmit-interval | O | 10..60000 | (sub-property of single-hop-session) Minimum desired control packet transmit interval Default value: 300 |
shutdown | O | "true" "false" | (sub-property of single-hop-session) BFD state of profile or session Default value: "false" |
passive-mode | O | "true" "false" | (sub-property of single-hop-session) Don't attempt to start session establishment. Default value: "false" |
required-echo-receive-interval | O | 0 10..60000 | (sub-property of single-hop-session) Minimum required echo packet receive interval Default value: 50 |
desired-echo-transmit-interval | O | 10..60000 | (sub-property of single-hop-session) Minimum desired echo packet transmission interval, this parameter only takes effect when configuring echo mode Default value: 50 |
echo-mode | O | "true" "false" | (sub-property of single-hop-session) Use echo packets to detect failures Default value: "false" |
BFD multiple hop sessions
Tree Diagrams
+--rw bfd
+--rw multi-hop-session* [dest-addr source-addr vrf]
| +--rw dest-addr
| +--rw vrf
| +--rw source-addr
| +--rw profile-name?
| +--rw detect-multiplier?
| +--rw required-receive-interval?
| +--rw desired-transmit-interval?
| +--rw shutdown?
| +--rw minimum-ttl?
| +--rw passive-mode?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
bfd | M | | Path-only node, has no configurable value. |
multi-hop-session | M | | (sub-property of bfd) Path-only node, has no configurable value. |
dest-addr | M | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of multi-hop-session) BFD remote IP address. |
vrf | M | "default" vrf name | (sub-property of multi-hop-session) Name of VRF instance. The default VRF is "default" |
source-addr | M | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of multi-hop-session) BFD local IP address. |
profile-name | O | string | (sub-property of multi-hop-session) BFD profile name |
detect-multiplier | O | 2..255 | (sub-property of multi-hop-session) peer detection multiplier Default value: 3 |
required-receive-interval | O | 10..60000 | (sub-property of multi-hop-session) Minimum desired control packet receive interval Default value: 300 |
desired-transmit-interval | O | 10..60000 | (sub-property of multi-hop-session) Minimum desired control packet transmit interval Default value: 300 |
shutdown | O | "true" "false" | (sub-property of multi-hop-session) BFD state of profile or session Default value: "false" |
minimum-ttl | O | 1..254 | (sub-property of multi-hop-session) Minimum expected TTL on received packets. Default value: 254 |
passive-mode | O | "true" "false" | (sub-property of multi-hop-session) Don't attempt to start session establishment. Default value: "false" |
BFD normal profiles
Tree Diagrams
+--rw bfd
+--rw profile* [profile-name]
| +--rw profile-name
| +--rw detect-multiplier?
| +--rw required-receive-interval?
| +--rw desired-transmit-interval?
| +--rw shutdown?
| +--rw passive-mode?
| +--rw required-echo-receive-interval?
| +--rw desired-echo-transmit-interval?
| +--rw minimum-ttl?
| +--rw echo-mode?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
bfd | M | | Path-only node, has no configurable value. |
profile | M | | (sub-property of bfd) Path-only node, has no configurable value. |
profile-name | M | string | (sub-property of profile) BFD profile name |
detect-multiplier | O | 2..255 | (sub-property of profile) peer detection multiplier Default value: 3 |
required-receive-interval | O | 10..60000 | (sub-property of profile) Minimum desired control packet receive interval Default value: 300 |
desired-transmit-interval | O | 10..60000 | (sub-property of profile) Minimum desired control packet transmit interval Default value: 300 |
shutdown | O | "true" "false" | (sub-property of profile) BFD state of profile or session Default value: "false" |
passive-mode | O | "true" "false" | (sub-property of profile) Don't attempt to start session establishment. Default value: "false" |
required-echo-receive-interval | O | 0 10..60000 | (sub-property of profile) Minimum required echo packet receive interval Default value: 50 |
desired-echo-transmit-interval | O | 10..60000 | (sub-property of profile) Minimum desired echo packet transmission interval, this parameter only takes effect when configuring echo mode Default value: 50 |
minimum-ttl | O | 1..254 | (sub-property of profile) Minimum expected TTL on received packets. Default value: 254 |
echo-mode | O | "true" "false" | (sub-property of profile) Use echo packets to detect failures Default value: "false" |
BFD accelerate profiles
Tree Diagrams
+--rw bfd
+--rw accelerate-profile* [name]
+--rw name
+--rw detect-multiplier?
+--rw required-receive-interval?
+--rw desired-transmit-interval?
+--rw shutdown?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
bfd | M | | Path-only node, has no configurable value. |
accelerate-profile | M | | (sub-property of bfd) Path-only node, has no configurable value. |
name | M | string | (sub-property of accelerate-profile) BFD accelerate profile name |
detect-multiplier | O | 1..15 | (sub-property of accelerate-profile) peer detection multiplier Default value: 3 |
required-receive-interval | O | 1..1000 | (sub-property of accelerate-profile) Minimum desired control packet receive interval Default value: 300 |
desired-transmit-interval | O | 1..1000 | (sub-property of accelerate-profile) Minimum desired control packet transmit interval Default value: 300 |
shutdown | O | "true" "false" | (sub-property of accelerate-profile) BFD state of profile or session Default value: "false" |
Show-bfd-counters
Tree Diagrams
+---x show-bfd-counters
| +---w input
| | +---w vrf?
| | +---w (peer)?
| | +--:(single-peer)
| | +---w dest-addr?
| | +---w source-addr?
| | +---w multihop?
| | +---w interface?
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-bfd-counters | M | | Path-only node, has no configurable value. show bfd counters information |
vrf | O | "default" vrf name | (sub-property of input) Name of VRF instance. Default value: "default" |
dest-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of input) BFD remote IP address. |
source-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of input) BFD local IP address. |
multihop | O | "true" "false" | (sub-property of input) BFD multihop Default value: "false" |
interface | O | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of input) Name of interface. |
data | RO | <anydata> | (sub-property of output) |
Show-bfd-brief
Tree Diagrams
+---x show-bfd-brief
| +---w input
| | +---w vrf?
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-bfd-brief | M | | Path-only node, has no configurable value. show bfd peers information briefly |
vrf | O | "default" vrf name | (sub-property of input) Name of VRF instance. Default value: "default" |
data | RO | <anydata> | (sub-property of output) |
Show-bfd-peer
Tree Diagrams
+---x show-bfd-peer
| +---w input
| | +---w vrf?
| | +---w (peer)?
| | +--:(single-peer)
| | +---w dest-addr?
| | +---w source-addr?
| | +---w multihop?
| | +---w interface?
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-bfd-peer | M | | Path-only node, has no configurable value. show bfd peer information |
vrf | O | "default" vrf name | (sub-property of input) Name of VRF instance. Default value: "default" |
dest-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of input) BFD remote IP address. |
source-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of input) BFD local IP address. |
multihop | O | "true" "false" | (sub-property of input) BFD multihop Default value: "false" |
interface | O | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of input) Name of interface. |
data | RO | <anydata> | (sub-property of output) |
Clear-bfd-counters
Tree Diagrams
+---x clear-bfd-counters
+---w input
+---w vrf?
+---w (peer)?
+--:(single-peer)
+---w dest-addr?
+---w source-addr?
+---w multihop?
+---w interface?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
clear-bfd-counters | M | | Path-only node, has no configurable value. Clear bfd peer counters |
vrf | O | "default" vrf name | (sub-property of input) Name of VRF instance. Default value: "default" |
dest-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of input) BFD remote IP address. |
source-addr | O | A.B.C.D XX:XX:XX:XX:XX:XX:XX:XX | (sub-property of input) BFD local IP address. |
multihop | O | "true" "false" | (sub-property of input) BFD multihop Default value: "false" |
interface | O | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of input) Name of interface. |